module fint2_mod
contains
double precision function fint2(u, eps, thick, layers, nper, eps_size)

! ******************************************************************
! *                                                                *
! * integration over the azimutal angle from 0.0 to phi < pi       *
! *                                                                *
! ******************************************************************

  use surlos_mod

  implicit none

  double precision, intent(in) :: u
  double complex, intent(in) :: eps(eps_size)
  double precision, intent(in) :: thick(eps_size)
  integer, intent(in) :: layers, nper, eps_size

  logical :: rational, user
  double precision :: a, arg, b, b2, c, ccoef, cospsi, dlimf, elleps, phi
  double precision :: phint, ru, sinpsi, um, usurlo, t, tanpsi, wn, x

  common / param / a, b, ccoef, elleps, cospsi, sinpsi, tanpsi, &
      ru, um, dlimf, wn, user, rational

!  write (*,*) 'fint2:'
!  write (*,*) 'thick: ', size(thick)
!  write (*,*) 'eps: ', size(eps)

  if (u == 0.0d0) then
    fint2 = 0.0d0
    return
  endif
  b2 = b**2
  c = (1.0d0 - elleps) * (cospsi * u)**2 + (b - ccoef) * (b + ccoef)
  if (dabs(a * c) > 1.0d-03 * b2) then
    x = (b - dsqrt(b2 - a * c)) / a
  else
    x = a * c / b2
    x = 0.5d0 * c * (1.d0 + 0.25d0 * x * (1.d0 + 0.5d0 * x * (1.d0 + 0.625d0 * x))) / b
  endif
  arg = x / u
  if (dabs(arg) > 1.0d0) then
    arg = dsign(1.0d0, arg)
  endif
  phi = dacos(arg)
  fint2 = phint(phi, tanpsi, u)
  if (rational) then
    return
  endif
  if (user) then
    fint2 = fint2 * usurlo(ru * u, wn)
  else
    fint2 = fint2 * surlos(ru * u, eps, thick, layers, nper)
    if (dlimf > 0.0d0) then
      t = ru * u * dlimf
      fint2 = fint2 * (1.d0 + t * dlog(t / (t + 0.26d0)))**2 / (1.d0 + 1.40d0 * t)
    endif
  endif
  return
end function fint2
end module fint2_mod
