      SUBROUTINE SICOT(F,M,H,X0)                                        
C   ******************************************************************* 
C   *                                                                 * 
C   * INTEGRAL TRANSFORM G(Y,X0) OF A REAL FUNCTION F(X) DEFINED BY   * 
C   *                                                                 * 
C   * G(X0,Y) = INTEGRAL OF F(X)/TANH(X/X0)*(1-COS(X*Y)) DX           * 
C   *                                                                 * 
C   * F(X) IS TABULATED ON THE MESH OF POINTS XJ = (J-1/2)*H ,        * 
C   * J = 1, 2, ..., N ,  WITH N = 2**M                               * 
C   * G(X0,Y) IS COMPUTED ON THE MESH OF POINTS YK = K*2PI/(N*H) ,    * 
C   * K = 0, 1, 2, ..., N-1                                           * 
C   *                                                                 * 
C   * INPUT ...                                                       * 
C   * F(J) CONTAINS THE VALUE OF F(XJ) , J = 1, 2, ..., N             * 
C   * M IS SUCH THAT N = 2**IABS(M)                                   * 
C   * H IS THE STEP SIZE (MUST BE POSITIVE)                           * 
C   *                                                                 * 
C   * OUTPUT ...                                                      * 
C   * F(K+1) CONTAINS G(X0,YK), K = 0, 1, ..., N-1                    * 
C   *                                                                 * 
C   * COMPUTING REMARKS ...                                           * 
C   * F IS A REAL ARRAY WITH DIMENSION N OR MORE                      * 
C   * IT IS SUPPOSED THAT F(X) IS ZERO FOR X > N*H                    * 
C   * EXTERNAL REFERENCE : SINTR (SINE TRANSFORM OF A REAL FUNCTION). * 
C   *                                                                 * 
C   ******************************************************************* 
      DIMENSION F(*)                                                    
      IF(M.EQ.0) THEN                                                   
         F(1) = 0.0D0                                                   
         RETURN                                                         
      ENDIF                                                             
      IF(H.LE.0.0 .OR. X0.LT.0.0) GOTO 9                                
      N = 2**IABS(M)                                                    
C                                                                       
C *** EVALUATE THE INTEGRAL FROM XJ TO INFINITY OF F(X)/TANH(X/X0) DX   
C     AND STORE THE RESULT IN F(J)                                      
C                                                                       
      C = 0.0                                                           
      IF(X0.GT.H/16.0) C = EXP(-H/X0)                                   
      S = 1.0-C                                                         
      E = C**2                                                          
      A = 0.25*H                                                        
      B = 0.25*X0                                                       
      DO 2 I=1,N                                                        
         IF(I.LT.N) F(I) = F(I)+F(I+1)                                  
         D = A                                                          
         IF(S.EQ.1.0) GOTO 1                                            
         SA = S                                                         
         C = C*E                                                        
         S = 1.0-C                                                      
         D = D+B*LOG(S/SA)                                              
    1    F(I) = F(I)*D                                                  
    2 CONTINUE                                                          
      J = N                                                             
      DO 3 I=2,N                                                        
         J = J-1                                                        
         F(J) = F(J)+F(J+1)                                             
    3 CONTINUE                                                          
      MSIGN = -IABS(M)                                                  
      CALL SINTR(F,MSIGN,H)                                             
      RETURN                                                            
    9 IF(H.LE.0.0) WRITE(6,10) H                                        
      IF(X0.LT.0.0) WRITE(6,11) X0                                      
   10 FORMAT(' *** INCORRECT STEP SIZE IN <SICOT>, H =',E15.6,' ***')   
   11 FORMAT(' *** INCORRECT INPUT IN <SICOT>, X0 =',E15.6,' ***')      
      STOP                                                              
      END                                                               
