      SUBROUTINE SINTR(F,MSIGN,H)                                       
C   ******************************************************************* 
C   *                                                                 * 
C   * INTEGRAL SINE TRANSFORM OF A REAL FUNCTION F(X)                 * 
C   *                                                                 * 
C   * G(Y) = INTEGRAL FROM ZERO TO INFINITY OF F(X)*SIN(X*Y) DX       * 
C   * IF MSIGN >= 0 OR                                                * 
C   * G(Y) = Y * INTEGRAL FROM ZERO TO INFINITY OF F(X)*SIN(X*Y) DX   * 
C   * IF MSIGN < 0                                                    * 
C   *                                                                 * 
C   * F(X) IS TABULATED ON THE MESH OF POINTS XJ = (J-1/2)*H ,        * 
C   * J = 1, 2, ..., N ,  WITH N = 2**IABS(MSIG)                      * 
C   * G(Y) IS COMPUTED ON THE MESH OF POINTS YK = K*2PI/(N*H) ,       * 
C   * K = 0, 1, 2, ..., N-1                                           * 
C   *                                                                 * 
C   * INPUT ...                                                       * 
C   * F(J) CONTAINS THE VALUE OF F(XJ) , J = 1, 2, ..., N             * 
C   * MSIGN IS SUCH THAT N = 2**IABS(MSIGN)                           * 
C   * H IS THE STEP SIZE (MUST BE POSITIVE)                           * 
C   *                                                                 * 
C   * OUTPUT ...                                                      * 
C   * F(K+1) CONTAINS G(YK), K = 0, 1, ..., N-1                       * 
C   *                                                                 * 
C   * COMPUTING REMARKS ...                                           * 
C   * F IS A REAL ARRAY WITH DIMENSION N OR MORE                      * 
C   * IT IS SUPPOSED THAT F(X) IS ZERO FOR X > N*H                    * 
C   *                                                                 * 
C   ******************************************************************* 
      DIMENSION F(*)                                                    
      IF(MSIGN.EQ.0) GOTO 16                                            
      IF(H.LE.0.0) GOTO 17                                              
C                                                                       
C *** FOR J AND K = 0, 1, 2 ... N/2-1, COMPUTE                          
C     S1 = SUM ( F(2*J+1)*COS(4*PI*K*J/N) - F(2*J+2)*SIN(4*PI*K*J/N) )  
C     S2 = SUM ( F(2*J+1)*SIN(4*PI*K*J/N) + F(2*J+2)*COS(4*PI*K*J/N) )  
C     STORE S1 IN F(2*K+1) AND S2 IN F(2*K+2)                           
C     (ADAPTED FROM CFFT ROUTINE, CERN LIBRARY MEMBER D704)             
C                                                                       
      M2 = IABS(MSIGN)-1                                                
      N = 2**M2                                                         
      IF(N.EQ.1) GOTO 10                                                
      NV2 = N/2                                                         
      NM1 = N-1                                                         
      J = 1                                                             
      DO 3 I=1,NM1                                                      
         IF(I.LT.J) THEN                                                
            I2 = I+I                                                    
            J2 = J+J                                                    
            TI = F(J2)                                                  
            F(J2) = F(I2)                                               
            F(I2) = TI                                                  
            I2 = I2-1                                                   
            J2 = J2-1                                                   
            TR = F(J2)                                                  
            F(J2) = F(I2)                                               
            F(I2) = TR                                                  
         ENDIF                                                          
         K = NV2                                                        
    1    IF(K.GE.J) GOTO 2                                              
         J = J-K                                                        
         K = K/2                                                        
         GOTO 1                                                         
    2    J = J+K                                                        
    3 CONTINUE                                                          
      DO 4 I=1,N,2                                                      
         I2 = I+I                                                       
         TI = F(I2+2)                                                   
         F(I2+2) = F(I2)-TI                                             
         F(I2) = F(I2)+TI                                               
         I2 = I2-1                                                      
         TR = F(I2+2)                                                   
         F(I2+2) = F(I2)-TR                                             
         F(I2) = F(I2)+TR                                               
    4 CONTINUE                                                          
      IF(M2.EQ.1) GOTO 10                                               
      C = 0.0                                                           
      S = 1.0                                                           
      LE = 2                                                            
      DO 8 L=2,M2                                                       
         WR = C                                                         
         WI = S                                                         
         UR = WR                                                        
         UI = WI                                                        
         C = SQRT(C*0.5+0.5)                                            
         S = S/(C+C)                                                    
         LE1 = LE                                                       
         LE = LE1+LE1                                                   
         DO 5 I=1,N,LE                                                  
            I2 = I+I                                                    
            IP2 = I2+LE                                                 
            TI = F(IP2)                                                 
            F(IP2) = F(I2)-TI                                           
            F(I2) = F(I2)+TI                                            
            I2 = I2-1                                                   
            IP2 = IP2-1                                                 
            TR = F(IP2)                                                 
            F(IP2) = F(I2)-TR                                           
            F(I2) = F(I2)+TR                                            
    5    CONTINUE                                                       
         DO 7 J=2,LE1                                                   
            DO 6 I=J,N,LE                                               
               I2 = I+I                                                 
               IP2 = I2+LE                                              
               TR = F(IP2-1)*UR-F(IP2)*UI                               
               TI = F(IP2)*UR+F(IP2-1)*UI                               
               F(IP2) = F(I2)-TI                                        
               F(I2) = F(I2)+TI                                         
               I2 = I2-1                                                
               IP2 = IP2-1                                              
               F(IP2) = F(I2)-TR                                        
               F(I2) = F(I2)+TR                                         
    6       CONTINUE                                                    
            TR = UR*WR-UI*WI                                            
            UI = UI*WR+UR*WI                                            
            UR = TR                                                     
    7    CONTINUE                                                       
    8 CONTINUE                                                          
C                                                                       
C *** FOR J AND K = 0, 1 ... N-1, TRANSFORM THE ARRAY F SO OBTAINED INTO
C     SUM F(J+1)*COS(2*PI*K*J/N) AND SUM F(J+1)*SIN(2*PI*K*J/N)         
C     AND MULTIPLY THE RESULTS BY (1-COS(2*PI*K/N)) AND SIN(2*PI*K/N)   
C                                                                       
   10 FNP1 = 4.0*(F(1)-F(2))                                            
      A = 3.1415926/N                                                   
      N2 = N+1                                                          
      N = 2*N                                                           
      IF(N2.EQ.2) GOTO 14                                               
      C = 1.0                                                           
      S = 0.0                                                           
      CA = COS(A)                                                       
      SA = SIN(A)                                                       
      K = N+1                                                           
      DO 11 J=3,N2,2                                                    
         K = K-2                                                        
         D = C                                                          
         C = D*CA-S*SA                                                  
         S = D*SA+S*CA                                                  
         TR1 = F(J)+F(K)                                                
         TI1 = F(J+1)-F(K+1)                                            
         D = F(J)-F(K)                                                  
         E = F(J+1)+F(K+1)                                              
         TR2 = D*S+E*C                                                  
         TI2 = E*S-D*C                                                  
         F(J) = (1.0-C)*(TR1+TR2)                                       
         F(J+1) = S*(TI1+TI2)                                           
         F(K) = (1.0+C)*(TR1-TR2)                                       
         F(K+1) = S*(TI2-TI1)                                           
   11 CONTINUE                                                          
      N2 = N2-1                                                         
      DO 12 J=2,N2                                                      
         J2 = J+J                                                       
         F(J) = F(J2-1)+F(J2)                                           
   12 CONTINUE                                                          
      DO 13 J=2,N2                                                      
         F(N+2-J) = F(J)                                                
   13 CONTINUE                                                          
      N2 = N2+1                                                         
   14 F(N2) = FNP1                                                      
      IF(MSIGN.LT.0) GOTO 16                                            
C                                                                       
C *** NORMALIZATION                                                     
C                                                                       
      C = 0.0                                                           
      A = (A+A)/H                                                       
      DO 15 J=2,N                                                       
         C = C+A                                                        
         F(J) = F(J)/C                                                  
   15 CONTINUE                                                          
   16 F(1) = 0.0                                                        
      RETURN                                                            
   17 WRITE(6,18) H                                                     
   18 FORMAT(' *** INCORRECT STEP SIZE IN <SINTR>, H =',E15.6,' ***')   
      STOP                                                              
      END                                                               
